crabnet.data.benchmark\_data.CritExam\_\_Ed package
===================================================

Module contents
---------------

.. automodule:: crabnet.data.benchmark_data.CritExam__Ed
   :members:
   :undoc-members:
   :show-inheritance:
